@@ -1,15 +1,11 @@
-from captur_ml_sdk.dtypes.generics import Image
+from captur_ml_sdk.dtypes.generics import Image, Meta
 
 from pydantic import (
-    BaseModel, HttpUrl
+    BaseModel
 )
 from typing import Optional
 
 
-class LivePredictMeta(BaseModel):
-    webhooks: Optional[HttpUrl]
-
-
 class Model(BaseModel):
     endpoint_id: str
     type: str
@@ -19,6 +15,6 @@ class Model(BaseModel):
 
 
 class ModelLivePredictRequest(BaseModel):
-    meta: Optional[LivePredictMeta] = None
+    meta: Optional[Meta] = None
     model: Model
     data: Image
