@@ -3,7 +3,7 @@ from typing import Optional
 
 
 class LivePredictEventData(BaseModel):
-    request_type: str
+    request_id: str
     endpoint_id: str
     model_type: str
     image_url: AnyUrl
